# FILE: options.tcl
#
# A resource file for the OOMMF project.
#
# Configurable options of Oc_Classes may be set in this file via calls 
# to [Oc_Option Add].  
#
# Each block below defines the default value of one configurable option
# in OOMMF (the value which would prevail if this file didn't exist).
# Some blocks include alternatives, commented out.  You may edit this
# file to configure OOMMF to use different option values.  However,
# future OOMMF distributions may overwrite this file.  OOMMF also
# queries the file ./local/options.tcl for configuraton information, if
# it exists, and that file will not be overwritten by future
# distributions of OOMMF.  To make permanent configuration changes to
# OOMMF, copy this file to ./local/options.tcl and edit it.

########################################################################
# The port on which the OOMMF host server listens for connections
Oc_Option Add * Net_Host port 15136
########################################################################
# The (partial) Tcl command used to launch a browser for HTML files.
# 
# OOMMF's native HTML browser:
Oc_Option Add * {} htmlBrowserCmd {Oc_Application Exec mmhelp}
#
# Netscape's Navigator/Communicator -- may need full path
# Oc_Option Add * {} htmlBrowserCmd {exec netscape}
#
# Microsoft's Internet Explorer -- may need full path
# Oc_Option Add * {} htmlBrowserCmd {exec iexplore}
########################################################################
# The file: URLs generated by the Oc_Class Oc_Url follow RFC 1738 and
# RFC 1808, so that they look like file://localhost/path/to/file.html .
# Change the value to 1 to generate file: URLs acceptable as input to
# Microsoft Internet Explorer in the form: file:/path/to/file.html
Oc_Option Add * Oc_Url msieCompatible 0
########################################################################
# Platform-generic default flags for compiling
# To enable compiler warnings, add '-warn 1'
# To enable debugger support, add '-debug 1'
Oc_Option Add * Platform cflags {}
########################################################################
# Platform-generic default flags for linking
Oc_Option Add * Platform lflags {}
########################################################################
# Whether Oc_Classes should enforce the 'const' keyword
Oc_Option Add * Oc_Class enforceConst 0
########################################################################
# Whether Oc_Classes should enforce the 'private' keyword
Oc_Option Add * Oc_Class enforcePrivate 0
########################################################################
########################################################################
# Evalute the file ./local/options.tcl if it exists.  

set fn [file join [file dirname [Oc_DirectPathname [info script]]] local \
        options.tcl]
if {[file readable $fn]} {
    if {[catch {source $fn} msg]} {
        error "Error sourcing $fn:
	$msg"
    }
}

