# FILE: hostGui.tcl
#

Oc_Class Net_HostGui {
    const public variable winpath
    const public variable outer_frame_options = "-bd 4 -relief ridge"
    public variable host
    private variable acctbuttons = {}
    private variable ctrlbar
    private variable panel
    private variable myEventHandlers = {}
    Constructor {basewinpath args} {
	# Don't add '.' suffix if there already is one.
	# (This happens chiefly when basewinpath is exactly '.')
	if {![string match {.} \
		[string index $basewinpath \
		[expr [string length $basewinpath]-1]]]} {
	    append basewinpath {.}
	}
	eval $this Configure -winpath ${basewinpath}w$this $args

	# Pack entire subwidget into a subframe.  This makes
	# housekeeping easier, since the only bindings on
	# $winpath will be ones added from inside the class,
	# and also all subwindows can be destroyed by simply
	# destroying $winpath.  (The instance destructor should
	# not "destroy" $frame, because $frame is owned external
	# to this class.
	eval frame $winpath $outer_frame_options
        set ctrlbar [frame $winpath.ctrl -relief groove]
        set panel [frame $winpath.panel -relief groove]
        set hostname [$host Cget -hostname]
        set hostlabel [label $ctrlbar.label -text $hostname:]
        pack $hostlabel -side left -in $ctrlbar -fill x -expand 0
        $this DisplayAccountButtons
        lappend myEventHandlers [em_eventHandler new Net_Account delete \
                [list $this DisplayAccountButtons]]
        lappend myEventHandlers [em_eventHandler new Net_Account Ready \
                [list $this DisplayAccountButtons]]
        pack $ctrlbar -side top -fill x -expand 0
        pack $panel -side top -fill both -expand 1

	# Widget bindings
	bind $winpath <Destroy> "+$this WinDestroy %W"
    }
    method DisplayAccountButtons {} {
        foreach w $acctbuttons {
            destroy $w
        }
        set acctbuttons {}
        foreach acct [Net_Account Instances] {
            if {[string match [$host Cget -hostname] [$acct Cget -hostname]]} {
                if {[$acct Ready]} {
                    set btn [checkbutton $ctrlbar.w$acct \
                            -text [$acct Cget -accountname] \
                            -variable ${acct}_BtnVar \
                            -command [list $acct ToggleGui $panel]]
                    lappend acctbuttons $btn
                    pack $btn -side left -in $ctrlbar -expand 0
                }
            }
        }
    }
    method WinDestroy { w } { winpath } {
	if {[string compare $winpath $w]!=0} { return } ;# Child destroy event
	$this Delete
    }
    private variable delete_in_progress = 0
    Destructor {
	# Protect against re-entrancy
	if { [info exists delete_in_progress] && \
		$delete_in_progress } { return }
	set delete_in_progress 1

        foreach handler $myEventHandlers {
            $handler delete
        }
        foreach w $acctbuttons {
            set varname [$w cget -variable]
            global $varname
            if {[set $varname]} {
                $w invoke
            }
        }
	# Delete everything else
	if {[info exists winpath] && [winfo exists $winpath]} {
	    # Destroy instance frame, all children, and bindings
	    destroy $winpath
	}
    }
}
