# FILE: em.tcl
#
# Emulation for some old interfaces from the em extension.

# The following Oc_Class emulates the old em_eventHandler command to
# support those old portions of the code which are still using it.
# It should eventually go away as that old code is upgraded to the
# new interface.

Oc_Class em_eventHandler {

    common level 0

    proc Generate { event taglist } {
        incr level
        set code [catch {
            Oc_EventHandler Bindtags fake$level $taglist
            Oc_EventHandler Generate fake$level $event
            Oc_EventHandler Bindtags fake$level {}
        } msg]
        incr level -1
        if {$code} {
            error $msg
        }
    }

    proc Bindings {args} {
        uplevel Oc_EventHandler Bindings $args
    }

    proc DeleteGroup {args} {
        uplevel Oc_EventHandler DeleteGroup $args
    }

    private variable realHandler

    Constructor {args} {
        eval Oc_EventHandler New realHandler $args
    }

    Destructor {
        $realHandler Delete
    }
  
    proc new {args} {
        uplevel $class New _ $args
    }
    method delete {args} {
        uplevel $this Delete $args
    }
}


# The next two Oc_Classes emulate an old interface to a logging mechanism
# to support those old portions of the code which are still using it.
# They should eventually go away as that old code is upgraded to use the
# newer logging facility.

Oc_Class em_log {
    public variable title = "Log"
    public variable dateformat = "\[%Y %b %d, %H:%M:%S %Z\] "
    Constructor {args} {
        eval $this Configure $args
        $this Append "Starting $title ..."
    }
    # Append a line to this log
    method Append { args } {
        # -nonewline is ignored
        if {[llength $args] == 1} {
            set msg [lindex $args 0]
        } elseif {([llength $args] == 2) \
                && [string match -nonewline [lindex $args 0]]} {
            set msg [lindex $args 1]
        } else {
            error "usage: <em_log instance> Append ?-nonewline? <msg>"
        }
        set msg "[clock format [clock seconds] -format $dateformat]$msg"
        Oc_Log Log $msg status
    }
    Destructor {
        em_eventHandler Generate delete [list $this $class]
    }
}

Oc_Class em_extension {
    const common log 
    ClassConstructor {
        em_log New log -dateformat "" \
                -title "[info nameofexecutable] application message log"
    }
    proc ApplicationLog {} {log} {
        return $log
    }
}

